@@ -26,10 +26,14 @@ class wallet:
             for item in items:
                 wallet = int(item[2])
                 bank = int(item[3])
-
+                
+            print(wallet)
+            print(self.amount)
                 
             sum = self.amount + wallet
             
+            print(sum)
+            
             c.execute(f"""UPDATE economy SET wallet = {sum}
                     WHERE user_ID = {self.user_ID}  
                 """)
@@ -61,4 +65,28 @@ class wallet:
         
         else:
             for item in items:
-                pass
+                wallet = int(item[1])
+                bank = int(item[2])
+                
+            if wallet >= self.amount:
+                sum = wallet - self.amount
+                net = sum + bank
+                
+                c.execute(f"""UPDATE economy SET wallet = {sum}
+                        WHERE user_ID = {self.user_ID}  
+                    """)
+                
+                conn.commit()
+                
+                c.execute(f"""UPDATE economy SET net = {net}
+                        WHERE user_ID = {self.user_ID}
+                    """)
+                
+                conn.commit()
+                conn.close()
+            
+            elif wallet < self.amount:
+                return None
+            
+            else:
+                return None
